#[non_exhaustive]pub enum Interpreter {
Unspecified,
Shell,
Powershell,
UnknownValue(UnknownValue),
}Expand description
The interpreter used to execute the a file.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Invalid for a Windows ExecStepConfig. For a Linux ExecStepConfig, the interpreter will be parsed from the shebang line of the script if unspecified.
Shell
Indicates that the script is run with /bin/sh on Linux and cmd
on Windows.
Powershell
Indicates that the file is run with PowerShell flags
-NonInteractive, -NoProfile, and -ExecutionPolicy Bypass.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Interpreter::value or Interpreter::name.
Implementations