#[non_exhaustive]pub enum PatchState {
Show 17 variants
Unspecified,
Pending,
Inactive,
Notified,
Started,
DownloadingPatches,
ApplyingPatches,
Rebooting,
Succeeded,
SucceededRebootRequired,
Failed,
Acked,
TimedOut,
RunningPrePatchStep,
RunningPostPatchStep,
NoAgentDetected,
UnknownValue(UnknownValue),
}Expand description
Patch state of an instance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified.
Pending
The instance is not yet notified.
Inactive
Instance is inactive and cannot be patched.
Notified
The instance is notified that it should be patched.
Started
The instance has started the patching process.
DownloadingPatches
The instance is downloading patches.
ApplyingPatches
The instance is applying patches.
Rebooting
The instance is rebooting.
Succeeded
The instance has completed applying patches.
SucceededRebootRequired
The instance has completed applying patches but a reboot is required.
Failed
The instance has failed to apply the patch.
Acked
The instance acked the notification and will start shortly.
TimedOut
The instance exceeded the time out while applying the patch.
RunningPrePatchStep
The instance is running the pre-patch step.
RunningPostPatchStep
The instance is running the post-patch step.
NoAgentDetected
The service could not detect the presence of the agent. Check to ensure that the agent is installed, running, and able to communicate with the service.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PatchState::value or PatchState::name.
Implementations