#[non_exhaustive]pub struct WindowsApplication {
pub display_name: String,
pub display_version: String,
pub publisher: String,
pub install_date: Option<Date>,
pub help_link: String,
/* private fields */
}Expand description
Contains information about a Windows application that is retrieved from the Windows Registry. For more information about these fields, see: https://docs.microsoft.com/en-us/windows/win32/msi/uninstall-registry-key
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringThe name of the application or product.
display_version: StringThe version of the product or application in string format.
publisher: StringThe name of the manufacturer for the product or application.
install_date: Option<Date>The last time this product received service. The value of this property is replaced each time a patch is applied or removed from the product or the command-line option is used to repair the product.
help_link: StringThe internet address for technical support.
Implementations
Sourceimpl WindowsApplication
impl WindowsApplication
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = WindowsApplication::new().set_display_name("example");Sourcepub fn set_display_version<T: Into<String>>(self, v: T) -> Self
pub fn set_display_version<T: Into<String>>(self, v: T) -> Self
Sets the value of display_version.
Example
ⓘ
let x = WindowsApplication::new().set_display_version("example");Sourcepub fn set_publisher<T: Into<String>>(self, v: T) -> Self
pub fn set_publisher<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_install_date<T>(self, v: T) -> Self
pub fn set_install_date<T>(self, v: T) -> Self
Sets the value of install_date.
Example
ⓘ
use google_cloud_type::model::Date;
let x = WindowsApplication::new().set_install_date(Date::default()/* use setters */);Sourcepub fn set_or_clear_install_date<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_install_date<T>(self, v: Option<T>) -> Self
Sets or clears the value of install_date.
Example
ⓘ
use google_cloud_type::model::Date;
let x = WindowsApplication::new().set_or_clear_install_date(Some(Date::default()/* use setters */));
let x = WindowsApplication::new().set_or_clear_install_date(None::<Date>);Trait Implementations
Sourceimpl Clone for WindowsApplication
impl Clone for WindowsApplication
Sourcefn clone(&self) -> WindowsApplication
fn clone(&self) -> WindowsApplication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WindowsApplication
impl Debug for WindowsApplication
Sourceimpl Default for WindowsApplication
impl Default for WindowsApplication
Sourcefn default() -> WindowsApplication
fn default() -> WindowsApplication
Returns the “default value” for a type. Read more
Sourceimpl Message for WindowsApplication
impl Message for WindowsApplication
Sourceimpl PartialEq for WindowsApplication
impl PartialEq for WindowsApplication
impl StructuralPartialEq for WindowsApplication