#[non_exhaustive]pub struct LabelSet {
pub labels: HashMap<String, String>,
/* private fields */
}Expand description
Message representing label set.
- A label is a key value pair set for a VM.
- A LabelSet is a set of labels.
- Labels within a LabelSet are ANDed. In other words, a LabelSet is applicable for a VM only if it matches all the labels in the LabelSet.
- Example: A LabelSet with 2 labels:
env=prodandtype=webserverwill only be applicable for those VMs with both labels present.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.labels: HashMap<String, String>Labels are identified by key/value pairs in this map. A VM should contain all the key/value pairs specified in this map to be selected.
Implementations