#[non_exhaustive]pub enum State {
Unspecified,
Started,
InstanceLookup,
Patching,
Succeeded,
CompletedWithErrors,
Canceled,
TimedOut,
UnknownValue(UnknownValue),
}Expand description
Enumeration of the various states a patch job passes through as it executes.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
State must be specified.
Started
The patch job was successfully initiated.
InstanceLookup
The patch job is looking up instances to run the patch on.
Patching
Instances are being patched.
Succeeded
Patch job completed successfully.
CompletedWithErrors
Patch job completed but there were errors.
Canceled
The patch job was canceled.
TimedOut
The patch job timed out.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations