#[non_exhaustive]pub struct CreatePatchDeploymentRequest {
pub parent: String,
pub patch_deployment_id: String,
pub patch_deployment: Option<PatchDeployment>,
/* private fields */
}Expand description
A request message for creating a patch deployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project to apply this patch deployment to in the form
projects/*.
patch_deployment_id: StringRequired. A name for the patch deployment in the project. When creating a name the following rules apply:
- Must contain only lowercase letters, numbers, and hyphens.
- Must start with a letter.
- Must be between 1-63 characters.
- Must end with a number or a letter.
- Must be unique within the project.
patch_deployment: Option<PatchDeployment>Required. The patch deployment to create.
Implementations
Sourceimpl CreatePatchDeploymentRequest
impl CreatePatchDeploymentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_patch_deployment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_patch_deployment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of patch_deployment_id.
Example
ⓘ
let x = CreatePatchDeploymentRequest::new().set_patch_deployment_id("example");Sourcepub fn set_patch_deployment<T>(self, v: T) -> Selfwhere
T: Into<PatchDeployment>,
pub fn set_patch_deployment<T>(self, v: T) -> Selfwhere
T: Into<PatchDeployment>,
Sets the value of patch_deployment.
Example
ⓘ
use google_cloud_osconfig_v1::model::PatchDeployment;
let x = CreatePatchDeploymentRequest::new().set_patch_deployment(PatchDeployment::default()/* use setters */);Sourcepub fn set_or_clear_patch_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchDeployment>,
pub fn set_or_clear_patch_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchDeployment>,
Sets or clears the value of patch_deployment.
Example
ⓘ
use google_cloud_osconfig_v1::model::PatchDeployment;
let x = CreatePatchDeploymentRequest::new().set_or_clear_patch_deployment(Some(PatchDeployment::default()/* use setters */));
let x = CreatePatchDeploymentRequest::new().set_or_clear_patch_deployment(None::<PatchDeployment>);Trait Implementations
Sourceimpl Clone for CreatePatchDeploymentRequest
impl Clone for CreatePatchDeploymentRequest
Sourcefn clone(&self) -> CreatePatchDeploymentRequest
fn clone(&self) -> CreatePatchDeploymentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePatchDeploymentRequest
impl Debug for CreatePatchDeploymentRequest
Sourceimpl Default for CreatePatchDeploymentRequest
impl Default for CreatePatchDeploymentRequest
Sourcefn default() -> CreatePatchDeploymentRequest
fn default() -> CreatePatchDeploymentRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for CreatePatchDeploymentRequest