#[non_exhaustive]pub struct ExecutePatchJobRequest {
pub parent: String,
pub description: String,
pub instance_filter: Option<PatchInstanceFilter>,
pub patch_config: Option<PatchConfig>,
pub duration: Option<Duration>,
pub dry_run: bool,
pub display_name: String,
pub rollout: Option<PatchRollout>,
/* private fields */
}Expand description
A request message to initiate patching across Compute Engine instances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project in which to run this patch in the form projects/*
description: StringDescription of the patch job. Length of the description is limited to 1024 characters.
instance_filter: Option<PatchInstanceFilter>Required. Instances to patch, either explicitly or filtered by some criteria such as zone or labels.
patch_config: Option<PatchConfig>Patch configuration being applied. If omitted, instances are patched using the default configurations.
duration: Option<Duration>Duration of the patch job. After the duration ends, the patch job times out.
dry_run: boolIf this patch is a dry-run only, instances are contacted but will do nothing.
display_name: StringDisplay name for this patch job. This does not have to be unique.
rollout: Option<PatchRollout>Rollout strategy of the patch job.
Implementations
Sourceimpl ExecutePatchJobRequest
impl ExecutePatchJobRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = ExecutePatchJobRequest::new().set_description("example");Sourcepub fn set_instance_filter<T>(self, v: T) -> Selfwhere
T: Into<PatchInstanceFilter>,
pub fn set_instance_filter<T>(self, v: T) -> Selfwhere
T: Into<PatchInstanceFilter>,
Sets the value of instance_filter.
Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = ExecutePatchJobRequest::new().set_instance_filter(PatchInstanceFilter::default()/* use setters */);Sourcepub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchInstanceFilter>,
pub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchInstanceFilter>,
Sets or clears the value of instance_filter.
Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = ExecutePatchJobRequest::new().set_or_clear_instance_filter(Some(PatchInstanceFilter::default()/* use setters */));
let x = ExecutePatchJobRequest::new().set_or_clear_instance_filter(None::<PatchInstanceFilter>);Sourcepub fn set_patch_config<T>(self, v: T) -> Selfwhere
T: Into<PatchConfig>,
pub fn set_patch_config<T>(self, v: T) -> Selfwhere
T: Into<PatchConfig>,
Sets the value of patch_config.
Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = ExecutePatchJobRequest::new().set_patch_config(PatchConfig::default()/* use setters */);Sourcepub fn set_or_clear_patch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchConfig>,
pub fn set_or_clear_patch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchConfig>,
Sets or clears the value of patch_config.
Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = ExecutePatchJobRequest::new().set_or_clear_patch_config(Some(PatchConfig::default()/* use setters */));
let x = ExecutePatchJobRequest::new().set_or_clear_patch_config(None::<PatchConfig>);Sourcepub fn set_duration<T>(self, v: T) -> Self
pub fn set_duration<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
Sourcepub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
pub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ExecutePatchJobRequest::new().set_display_name("example");Sourcepub fn set_rollout<T>(self, v: T) -> Selfwhere
T: Into<PatchRollout>,
pub fn set_rollout<T>(self, v: T) -> Selfwhere
T: Into<PatchRollout>,
Sourcepub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchRollout>,
pub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchRollout>,