#[non_exhaustive]pub struct GetInventoryRequest {
pub name: String,
pub view: InventoryView,
/* private fields */
}Expand description
A request message for getting inventory data for the specified VM.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. API resource name for inventory resource.
Format:
projects/{project}/locations/{location}/instances/{instance}/inventory
For {project}, either project-number or project-id can be provided.
For {instance}, either Compute Engine instance-id or instance-name
can be provided.
view: InventoryViewInventory view indicating what information should be included in the inventory resource. If unspecified, the default view is BASIC.
Implementations