#[non_exhaustive]pub struct Inventory {
pub name: String,
pub os_info: Option<OsInfo>,
pub items: HashMap<String, Item>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
This API resource represents the available inventory data for a Compute Engine virtual machine (VM) instance at a given point in time.
You can use this API resource to determine the inventory data of your VM.
For more information, see Information provided by OS inventory management.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The Inventory API resource name.
Format:
projects/{project_number}/locations/{location}/instances/{instance_id}/inventory
os_info: Option<OsInfo>Base level operating system information for the VM.
items: HashMap<String, Item>Inventory items related to the VM keyed by an opaque unique identifier for each inventory item. The identifier is unique to each distinct and addressable inventory item and will change, when there is a new package version.
update_time: Option<Timestamp>Output only. Timestamp of the last reported inventory for the VM.
Implementations
Sourceimpl Inventory
impl Inventory
Sourcepub fn set_os_info<T>(self, v: T) -> Self
pub fn set_os_info<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_os_info<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_os_info<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Inventory::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Inventory::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Inventory::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Inventory