#[non_exhaustive]pub struct ListOSPolicyAssignmentReportsRequest {
pub parent: String,
pub page_size: i32,
pub filter: String,
pub page_token: String,
/* private fields */
}Expand description
List the OS policy assignment reports for VM instances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource name.
Format:
projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/reports
For {project}, either project-number or project-id can be provided.
For {instance}, either instance-name, instance-id, or - can be
provided. If ‘-’ is provided, the response will include
OSPolicyAssignmentReports for all instances in the project/location.
For {assignment}, either assignment-id or - can be provided. If ‘-’
is provided, the response will include OSPolicyAssignmentReports for all
OSPolicyAssignments in the project/location.
Either {instance} or {assignment} must be -.
For example:
projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/-/reports
returns all reports for the instance
projects/{project}/locations/{location}/instances/-/osPolicyAssignments/{assignment-id}/reports
returns all the reports for the given assignment across all instances.
projects/{project}/locations/{location}/instances/-/osPolicyAssignments/-/reports
returns all the reports for all assignments across all instances.
page_size: i32The maximum number of results to return.
filter: StringIf provided, this field specifies the criteria that must be met by the
OSPolicyAssignmentReport API resource that is included in the response.
page_token: StringA pagination token returned from a previous call to the
ListOSPolicyAssignmentReports method that indicates where this listing
should continue from.
Implementations
Sourceimpl ListOSPolicyAssignmentReportsRequest
impl ListOSPolicyAssignmentReportsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListOSPolicyAssignmentReportsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListOSPolicyAssignmentReportsRequest
impl Clone for ListOSPolicyAssignmentReportsRequest
Sourcefn clone(&self) -> ListOSPolicyAssignmentReportsRequest
fn clone(&self) -> ListOSPolicyAssignmentReportsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListOSPolicyAssignmentReportsRequest
impl Default for ListOSPolicyAssignmentReportsRequest
Sourcefn default() -> ListOSPolicyAssignmentReportsRequest
fn default() -> ListOSPolicyAssignmentReportsRequest
impl StructuralPartialEq for ListOSPolicyAssignmentReportsRequest