#[non_exhaustive]pub struct ListOSPolicyAssignmentRevisionsRequest {
pub name: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
A request message to list revisions for a OS policy assignment
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the OS policy assignment to list revisions for.
page_size: i32The maximum number of revisions to return.
page_token: StringA pagination token returned from a previous call to
ListOSPolicyAssignmentRevisions that indicates where this listing should
continue from.
Implementations
Sourceimpl ListOSPolicyAssignmentRevisionsRequest
impl ListOSPolicyAssignmentRevisionsRequest
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListOSPolicyAssignmentRevisionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListOSPolicyAssignmentRevisionsRequest
impl Clone for ListOSPolicyAssignmentRevisionsRequest
Sourcefn clone(&self) -> ListOSPolicyAssignmentRevisionsRequest
fn clone(&self) -> ListOSPolicyAssignmentRevisionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListOSPolicyAssignmentRevisionsRequest
impl Default for ListOSPolicyAssignmentRevisionsRequest
Sourcefn default() -> ListOSPolicyAssignmentRevisionsRequest
fn default() -> ListOSPolicyAssignmentRevisionsRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListOSPolicyAssignmentRevisionsRequest