#[non_exhaustive]pub struct ListOSPolicyAssignmentRevisionsResponse {
pub os_policy_assignments: Vec<OSPolicyAssignment>,
pub next_page_token: String,
/* private fields */
}Expand description
A response message for listing all revisions for a OS policy assignment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.os_policy_assignments: Vec<OSPolicyAssignment>The OS policy assignment revisions
next_page_token: StringThe pagination token to retrieve the next page of OS policy assignment revisions.
Implementations
Sourceimpl ListOSPolicyAssignmentRevisionsResponse
impl ListOSPolicyAssignmentRevisionsResponse
Sourcepub fn set_os_policy_assignments<T, V>(self, v: T) -> Self
pub fn set_os_policy_assignments<T, V>(self, v: T) -> Self
Sets the value of os_policy_assignments.
Example
ⓘ
use google_cloud_osconfig_v1::model::OSPolicyAssignment;
let x = ListOSPolicyAssignmentRevisionsResponse::new()
.set_os_policy_assignments([
OSPolicyAssignment::default()/* use setters */,
OSPolicyAssignment::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListOSPolicyAssignmentRevisionsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListOSPolicyAssignmentRevisionsResponse
impl Clone for ListOSPolicyAssignmentRevisionsResponse
Sourcefn clone(&self) -> ListOSPolicyAssignmentRevisionsResponse
fn clone(&self) -> ListOSPolicyAssignmentRevisionsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListOSPolicyAssignmentRevisionsResponse
impl Default for ListOSPolicyAssignmentRevisionsResponse
Sourcefn default() -> ListOSPolicyAssignmentRevisionsResponse
fn default() -> ListOSPolicyAssignmentRevisionsResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListOSPolicyAssignmentRevisionsResponse