#[non_exhaustive]pub struct ListPatchJobsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
A request message for listing patch jobs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. In the form of projects/*
page_size: i32The maximum number of instance status to return.
page_token: StringA pagination token returned from a previous call that indicates where this listing should continue from.
filter: StringIf provided, this field specifies the criteria that must be met by patch jobs to be included in the response. Currently, filtering is only available on the patch_deployment field.
Implementations
Sourceimpl ListPatchJobsRequest
impl ListPatchJobsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListPatchJobsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListPatchJobsRequest
impl Clone for ListPatchJobsRequest
Sourcefn clone(&self) -> ListPatchJobsRequest
fn clone(&self) -> ListPatchJobsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListPatchJobsRequest
impl Debug for ListPatchJobsRequest
Sourceimpl Default for ListPatchJobsRequest
impl Default for ListPatchJobsRequest
Sourcefn default() -> ListPatchJobsRequest
fn default() -> ListPatchJobsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListPatchJobsRequest
impl Message for ListPatchJobsRequest
Sourceimpl PartialEq for ListPatchJobsRequest
impl PartialEq for ListPatchJobsRequest
impl StructuralPartialEq for ListPatchJobsRequest