OSPolicyAssignment

Struct OSPolicyAssignment 

#[non_exhaustive]
pub struct OSPolicyAssignment {
Show 13 fields pub name: String, pub description: String, pub os_policies: Vec<OSPolicy>, pub instance_filter: Option<InstanceFilter>, pub rollout: Option<Rollout>, pub revision_id: String, pub revision_create_time: Option<Timestamp>, pub etag: String, pub rollout_state: RolloutState, pub baseline: bool, pub deleted: bool, pub reconciling: bool, pub uid: String, /* private fields */
}
OS policy assignment is an API resource that is used to apply a set of OS policies to a dynamically targeted group of Compute Engine VM instances.

An OS policy is used to define the desired state configuration for a Compute Engine VM instance through a set of configuration resources that provide capabilities such as installing or removing software packages, or executing a script.

For more information, see OS policy and OS policy assignment.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Resource name.

Format: projects/{project_number}/locations/{location}/osPolicyAssignments/{os_policy_assignment_id}

This field is ignored when you create an OS policy assignment.

description: String

OS policy assignment description. Length of the description is limited to 1024 characters.

os_policies: Vec<OSPolicy>

Required. List of OS policies to be applied to the VMs.

instance_filter: Option<InstanceFilter>

Required. Filter to select VMs.

rollout: Option<Rollout>

Required. Rollout to deploy the OS policy assignment. A rollout is triggered in the following situations:

  1. OSPolicyAssignment is created.
  2. OSPolicyAssignment is updated and the update contains changes to one of the following fields:
    • instance_filter
    • os_policies
  3. OSPolicyAssignment is deleted.
revision_id: String

Output only. The assignment revision ID A new revision is committed whenever a rollout is triggered for a OS policy assignment

revision_create_time: Option<Timestamp>

Output only. The timestamp that the revision was created.

etag: String

The etag for this OS policy assignment. If this is provided on update, it must match the server’s etag.

rollout_state: RolloutState

Output only. OS policy assignment rollout state

baseline: bool

Output only. Indicates that this revision has been successfully rolled out in this zone and new VMs will be assigned OS policies from this revision.

For a given OS policy assignment, there is only one revision with a value of true for this field.

deleted: bool

Output only. Indicates that this revision deletes the OS policy assignment.

reconciling: bool

Output only. Indicates that reconciliation is in progress for the revision. This value is true when the rollout_state is one of:

  • IN_PROGRESS
  • CANCELLING
uid: String

Output only. Server generated unique id for the OS policy assignment resource.

Implementations

Source

impl OSPolicyAssignment

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = OSPolicyAssignment::new().set_name(format!("projects/{project_id}/locations/{location_id}/osPolicyAssignments/{os_policy_assignment_id}"));
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = OSPolicyAssignment::new().set_description("example");
pub fn set_os_policies<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<OSPolicy>,

Sets the value of os_policies.

Example
use google_cloud_osconfig_v1::model::OSPolicy;
let x = OSPolicyAssignment::new()
    .set_os_policies([
        OSPolicy::default()/* use setters */,
        OSPolicy::default()/* use (different) setters */,
    ]);
pub fn set_instance_filter<T>(self, v: T) -> Self
where T: Into<InstanceFilter>,

Sets the value of instance_filter.

Example
use google_cloud_osconfig_v1::model::os_policy_assignment::InstanceFilter;
let x = OSPolicyAssignment::new().set_instance_filter(InstanceFilter::default()/* use setters */);
pub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Self
where T: Into<InstanceFilter>,

Sets or clears the value of instance_filter.

Example
use google_cloud_osconfig_v1::model::os_policy_assignment::InstanceFilter;
let x = OSPolicyAssignment::new().set_or_clear_instance_filter(Some(InstanceFilter::default()/* use setters */));
let x = OSPolicyAssignment::new().set_or_clear_instance_filter(None::<InstanceFilter>);
pub fn set_rollout<T>(self, v: T) -> Self
where T: Into<Rollout>,

Sets the value of rollout.

Example
use google_cloud_osconfig_v1::model::os_policy_assignment::Rollout;
let x = OSPolicyAssignment::new().set_rollout(Rollout::default()/* use setters */);
pub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Self
where T: Into<Rollout>,

Sets or clears the value of rollout.

Example
use google_cloud_osconfig_v1::model::os_policy_assignment::Rollout;
let x = OSPolicyAssignment::new().set_or_clear_rollout(Some(Rollout::default()/* use setters */));
let x = OSPolicyAssignment::new().set_or_clear_rollout(None::<Rollout>);
pub fn set_revision_id<T: Into<String>>(self, v: T) -> Self

Sets the value of revision_id.

Example
let x = OSPolicyAssignment::new().set_revision_id("example");
pub fn set_revision_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of revision_create_time.

Example
use wkt::Timestamp;
let x = OSPolicyAssignment::new().set_revision_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_revision_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of revision_create_time.

Example
use wkt::Timestamp;
let x = OSPolicyAssignment::new().set_or_clear_revision_create_time(Some(Timestamp::default()/* use setters */));
let x = OSPolicyAssignment::new().set_or_clear_revision_create_time(None::<Timestamp>);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = OSPolicyAssignment::new().set_etag("example");
pub fn set_rollout_state<T: Into<RolloutState>>(self, v: T) -> Self

Sets the value of rollout_state.

Example
use google_cloud_osconfig_v1::model::os_policy_assignment::RolloutState;
let x0 = OSPolicyAssignment::new().set_rollout_state(RolloutState::InProgress);
let x1 = OSPolicyAssignment::new().set_rollout_state(RolloutState::Cancelling);
let x2 = OSPolicyAssignment::new().set_rollout_state(RolloutState::Cancelled);
pub fn set_baseline<T: Into<bool>>(self, v: T) -> Self

Sets the value of baseline.

Example
let x = OSPolicyAssignment::new().set_baseline(true);
pub fn set_deleted<T: Into<bool>>(self, v: T) -> Self

Sets the value of deleted.

Example
let x = OSPolicyAssignment::new().set_deleted(true);
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = OSPolicyAssignment::new().set_reconciling(true);
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = OSPolicyAssignment::new().set_uid("example");