#[non_exhaustive]pub struct PatchConfig {
pub reboot_config: RebootConfig,
pub apt: Option<AptSettings>,
pub yum: Option<YumSettings>,
pub goo: Option<GooSettings>,
pub zypper: Option<ZypperSettings>,
pub windows_update: Option<WindowsUpdateSettings>,
pub pre_step: Option<ExecStep>,
pub post_step: Option<ExecStep>,
pub mig_instances_allowed: bool,
/* private fields */
}Expand description
Patch configuration specifications. Contains details on how to apply the patch(es) to a VM instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reboot_config: RebootConfigPost-patch reboot settings.
apt: Option<AptSettings>Apt update settings. Use this setting to override the default apt patch
rules.
yum: Option<YumSettings>Yum update settings. Use this setting to override the default yum patch
rules.
goo: Option<GooSettings>Goo update settings. Use this setting to override the default goo patch
rules.
zypper: Option<ZypperSettings>Zypper update settings. Use this setting to override the default zypper
patch rules.
windows_update: Option<WindowsUpdateSettings>Windows update settings. Use this override the default windows patch rules.
pre_step: Option<ExecStep>The ExecStep to run before the patch update.
post_step: Option<ExecStep>The ExecStep to run after the patch update.
mig_instances_allowed: boolAllows the patch job to run on Managed instance groups (MIGs).
Implementations
Sourceimpl PatchConfig
impl PatchConfig
Sourcepub fn set_reboot_config<T: Into<RebootConfig>>(self, v: T) -> Self
pub fn set_reboot_config<T: Into<RebootConfig>>(self, v: T) -> Self
Sets the value of reboot_config.
Example
use google_cloud_osconfig_v1::model::patch_config::RebootConfig;
let x0 = PatchConfig::new().set_reboot_config(RebootConfig::Default);
let x1 = PatchConfig::new().set_reboot_config(RebootConfig::Always);
let x2 = PatchConfig::new().set_reboot_config(RebootConfig::Never);Sourcepub fn set_apt<T>(self, v: T) -> Selfwhere
T: Into<AptSettings>,
pub fn set_apt<T>(self, v: T) -> Selfwhere
T: Into<AptSettings>,
Sourcepub fn set_or_clear_apt<T>(self, v: Option<T>) -> Selfwhere
T: Into<AptSettings>,
pub fn set_or_clear_apt<T>(self, v: Option<T>) -> Selfwhere
T: Into<AptSettings>,
Sourcepub fn set_yum<T>(self, v: T) -> Selfwhere
T: Into<YumSettings>,
pub fn set_yum<T>(self, v: T) -> Selfwhere
T: Into<YumSettings>,
Sourcepub fn set_or_clear_yum<T>(self, v: Option<T>) -> Selfwhere
T: Into<YumSettings>,
pub fn set_or_clear_yum<T>(self, v: Option<T>) -> Selfwhere
T: Into<YumSettings>,
Sourcepub fn set_goo<T>(self, v: T) -> Selfwhere
T: Into<GooSettings>,
pub fn set_goo<T>(self, v: T) -> Selfwhere
T: Into<GooSettings>,
Sourcepub fn set_or_clear_goo<T>(self, v: Option<T>) -> Selfwhere
T: Into<GooSettings>,
pub fn set_or_clear_goo<T>(self, v: Option<T>) -> Selfwhere
T: Into<GooSettings>,
Sourcepub fn set_zypper<T>(self, v: T) -> Selfwhere
T: Into<ZypperSettings>,
pub fn set_zypper<T>(self, v: T) -> Selfwhere
T: Into<ZypperSettings>,
Sourcepub fn set_or_clear_zypper<T>(self, v: Option<T>) -> Selfwhere
T: Into<ZypperSettings>,
pub fn set_or_clear_zypper<T>(self, v: Option<T>) -> Selfwhere
T: Into<ZypperSettings>,
Sourcepub fn set_windows_update<T>(self, v: T) -> Selfwhere
T: Into<WindowsUpdateSettings>,
pub fn set_windows_update<T>(self, v: T) -> Selfwhere
T: Into<WindowsUpdateSettings>,
Sets the value of windows_update.
Example
use google_cloud_osconfig_v1::model::WindowsUpdateSettings;
let x = PatchConfig::new().set_windows_update(WindowsUpdateSettings::default()/* use setters */);Sourcepub fn set_or_clear_windows_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<WindowsUpdateSettings>,
pub fn set_or_clear_windows_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<WindowsUpdateSettings>,
Sets or clears the value of windows_update.
Example
use google_cloud_osconfig_v1::model::WindowsUpdateSettings;
let x = PatchConfig::new().set_or_clear_windows_update(Some(WindowsUpdateSettings::default()/* use setters */));
let x = PatchConfig::new().set_or_clear_windows_update(None::<WindowsUpdateSettings>);Sourcepub fn set_pre_step<T>(self, v: T) -> Self
pub fn set_pre_step<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_pre_step<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_pre_step<T>(self, v: Option<T>) -> Self
Sourcepub fn set_post_step<T>(self, v: T) -> Self
pub fn set_post_step<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_post_step<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_post_step<T>(self, v: Option<T>) -> Self
Sourcepub fn set_mig_instances_allowed<T: Into<bool>>(self, v: T) -> Self
pub fn set_mig_instances_allowed<T: Into<bool>>(self, v: T) -> Self
Sets the value of mig_instances_allowed.
Example
let x = PatchConfig::new().set_mig_instances_allowed(true);Trait Implementations
Sourceimpl Clone for PatchConfig
impl Clone for PatchConfig
Sourcefn clone(&self) -> PatchConfig
fn clone(&self) -> PatchConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PatchConfig
impl Debug for PatchConfig
Sourceimpl Default for PatchConfig
impl Default for PatchConfig
Sourcefn default() -> PatchConfig
fn default() -> PatchConfig
Sourceimpl Message for PatchConfig
impl Message for PatchConfig
Sourceimpl PartialEq for PatchConfig
impl PartialEq for PatchConfig
impl StructuralPartialEq for PatchConfig