PatchJob

Struct PatchJob 

#[non_exhaustive]
pub struct PatchJob {
Show 15 fields pub name: String, pub display_name: String, pub description: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub state: State, pub instance_filter: Option<PatchInstanceFilter>, pub patch_config: Option<PatchConfig>, pub duration: Option<Duration>, pub instance_details_summary: Option<InstanceDetailsSummary>, pub dry_run: bool, pub error_message: String, pub percent_complete: f64, pub patch_deployment: String, pub rollout: Option<PatchRollout>, /* private fields */
}
A high level representation of a patch job that is either in progress or has completed.

Instance details are not included in the job. To paginate through instance details, use ListPatchJobInstanceDetails.

For more information about patch jobs, see Creating patch jobs.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Unique identifier for this patch job in the form projects/*/patchJobs/*

display_name: String

Display name for this patch job. This is not a unique identifier.

description: String

Description of the patch job. Length of the description is limited to 1024 characters.

create_time: Option<Timestamp>

Time this patch job was created.

update_time: Option<Timestamp>

Last time this patch job was updated.

state: State

The current state of the PatchJob.

instance_filter: Option<PatchInstanceFilter>

Instances to patch.

patch_config: Option<PatchConfig>

Patch configuration being applied.

duration: Option<Duration>

Duration of the patch job. After the duration ends, the patch job times out.

instance_details_summary: Option<InstanceDetailsSummary>

Summary of instance details.

dry_run: bool

If this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance.

error_message: String

If this patch job failed, this message provides information about the failure.

percent_complete: f64

Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete.

patch_deployment: String

Output only. Name of the patch deployment that created this patch job.

rollout: Option<PatchRollout>

Rollout strategy being applied.

Implementations

Source

impl PatchJob

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = PatchJob::new().set_name(format!("projects/{project_id}/patchJobs/{patch_job_id}"));
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = PatchJob::new().set_display_name("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = PatchJob::new().set_description("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = PatchJob::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = PatchJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PatchJob::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = PatchJob::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = PatchJob::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PatchJob::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_osconfig_v1::model::patch_job::State;
let x0 = PatchJob::new().set_state(State::Started);
let x1 = PatchJob::new().set_state(State::InstanceLookup);
let x2 = PatchJob::new().set_state(State::Patching);
pub fn set_instance_filter<T>(self, v: T) -> Self

Sets the value of instance_filter.

Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = PatchJob::new().set_instance_filter(PatchInstanceFilter::default()/* use setters */);
pub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Self

Sets or clears the value of instance_filter.

Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = PatchJob::new().set_or_clear_instance_filter(Some(PatchInstanceFilter::default()/* use setters */));
let x = PatchJob::new().set_or_clear_instance_filter(None::<PatchInstanceFilter>);
pub fn set_patch_config<T>(self, v: T) -> Self
where T: Into<PatchConfig>,

Sets the value of patch_config.

Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = PatchJob::new().set_patch_config(PatchConfig::default()/* use setters */);
pub fn set_or_clear_patch_config<T>(self, v: Option<T>) -> Self
where T: Into<PatchConfig>,

Sets or clears the value of patch_config.

Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = PatchJob::new().set_or_clear_patch_config(Some(PatchConfig::default()/* use setters */));
let x = PatchJob::new().set_or_clear_patch_config(None::<PatchConfig>);
pub fn set_duration<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of duration.

Example
use wkt::Duration;
let x = PatchJob::new().set_duration(Duration::default()/* use setters */);
pub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of duration.

Example
use wkt::Duration;
let x = PatchJob::new().set_or_clear_duration(Some(Duration::default()/* use setters */));
let x = PatchJob::new().set_or_clear_duration(None::<Duration>);
pub fn set_instance_details_summary<T>(self, v: T) -> Self

Sets the value of instance_details_summary.

Example
use google_cloud_osconfig_v1::model::patch_job::InstanceDetailsSummary;
let x = PatchJob::new().set_instance_details_summary(InstanceDetailsSummary::default()/* use setters */);
pub fn set_or_clear_instance_details_summary<T>(self, v: Option<T>) -> Self

Sets or clears the value of instance_details_summary.

Example
use google_cloud_osconfig_v1::model::patch_job::InstanceDetailsSummary;
let x = PatchJob::new().set_or_clear_instance_details_summary(Some(InstanceDetailsSummary::default()/* use setters */));
let x = PatchJob::new().set_or_clear_instance_details_summary(None::<InstanceDetailsSummary>);
pub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self

Sets the value of dry_run.

Example
let x = PatchJob::new().set_dry_run(true);
pub fn set_error_message<T: Into<String>>(self, v: T) -> Self

Sets the value of error_message.

Example
let x = PatchJob::new().set_error_message("example");
pub fn set_percent_complete<T: Into<f64>>(self, v: T) -> Self

Sets the value of percent_complete.

Example
let x = PatchJob::new().set_percent_complete(42.0);
pub fn set_patch_deployment<T: Into<String>>(self, v: T) -> Self

Sets the value of patch_deployment.

Example
let x = PatchJob::new().set_patch_deployment(format!("projects/{project_id}/patchDeployments/{patch_deployment_id}"));
pub fn set_rollout<T>(self, v: T) -> Self
where T: Into<PatchRollout>,

Sets the value of rollout.

Example
use google_cloud_osconfig_v1::model::PatchRollout;
let x = PatchJob::new().set_rollout(PatchRollout::default()/* use setters */);
pub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Self
where T: Into<PatchRollout>,

Sets or clears the value of rollout.

Example
use google_cloud_osconfig_v1::model::PatchRollout;
let x = PatchJob::new().set_or_clear_rollout(Some(PatchRollout::default()/* use setters */));
let x = PatchJob::new().set_or_clear_rollout(None::<PatchRollout>);