#[non_exhaustive]pub struct WindowsUpdateSettings {
pub classifications: Vec<Classification>,
pub excludes: Vec<String>,
pub exclusive_patches: Vec<String>,
/* private fields */
}Expand description
Windows patching is performed using the Windows Update Agent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.classifications: Vec<Classification>Only apply updates of these windows update classifications. If empty, all updates are applied.
excludes: Vec<String>List of KBs to exclude from update.
exclusive_patches: Vec<String>An exclusive list of kbs to be updated. These are the only patches that will be updated. This field must not be used with other patch configurations.
Implementations
Sourceimpl WindowsUpdateSettings
impl WindowsUpdateSettings
Sourcepub fn set_classifications<T, V>(self, v: T) -> Self
pub fn set_classifications<T, V>(self, v: T) -> Self
Sets the value of classifications.
Example
ⓘ
use google_cloud_osconfig_v1::model::windows_update_settings::Classification;
let x = WindowsUpdateSettings::new().set_classifications([
Classification::Critical,
Classification::Security,
Classification::Definition,
]);Sourcepub fn set_excludes<T, V>(self, v: T) -> Self
pub fn set_excludes<T, V>(self, v: T) -> Self
Sourcepub fn set_exclusive_patches<T, V>(self, v: T) -> Self
pub fn set_exclusive_patches<T, V>(self, v: T) -> Self
Sets the value of exclusive_patches.
Example
ⓘ
let x = WindowsUpdateSettings::new().set_exclusive_patches(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for WindowsUpdateSettings
impl Clone for WindowsUpdateSettings
Sourcefn clone(&self) -> WindowsUpdateSettings
fn clone(&self) -> WindowsUpdateSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WindowsUpdateSettings
impl Debug for WindowsUpdateSettings
Sourceimpl Default for WindowsUpdateSettings
impl Default for WindowsUpdateSettings
Sourcefn default() -> WindowsUpdateSettings
fn default() -> WindowsUpdateSettings
Returns the “default value” for a type. Read more
Sourceimpl Message for WindowsUpdateSettings
impl Message for WindowsUpdateSettings
Sourceimpl PartialEq for WindowsUpdateSettings
impl PartialEq for WindowsUpdateSettings
impl StructuralPartialEq for WindowsUpdateSettings