#[non_exhaustive]pub struct SoftwarePackage {
pub details: Option<Details>,
/* private fields */
}Expand description
Software package information of the operating system.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.details: Option<Details>Information about the different types of software packages.
Implementations
Sourceimpl SoftwarePackage
impl SoftwarePackage
Sourcepub fn set_details<T: Into<Option<Details>>>(self, v: T) -> Self
pub fn set_details<T: Into<Option<Details>>>(self, v: T) -> Self
Sets the value of details.
Note that all the setters affecting details are mutually
exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_details(Some(
google_cloud_osconfig_v1::model::inventory::software_package::Details::YumPackage(VersionedPackage::default().into())));Sourcepub fn yum_package(&self) -> Option<&Box<VersionedPackage>>
pub fn yum_package(&self) -> Option<&Box<VersionedPackage>>
The value of details
if it holds a YumPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_yum_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
pub fn set_yum_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
Sets the value of details
to hold a YumPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_yum_package(VersionedPackage::default()/* use setters */);
assert!(x.yum_package().is_some());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn apt_package(&self) -> Option<&Box<VersionedPackage>>
pub fn apt_package(&self) -> Option<&Box<VersionedPackage>>
The value of details
if it holds a AptPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_apt_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
pub fn set_apt_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
Sets the value of details
to hold a AptPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_apt_package(VersionedPackage::default()/* use setters */);
assert!(x.apt_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn zypper_package(&self) -> Option<&Box<VersionedPackage>>
pub fn zypper_package(&self) -> Option<&Box<VersionedPackage>>
The value of details
if it holds a ZypperPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_zypper_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
pub fn set_zypper_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
Sets the value of details
to hold a ZypperPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_zypper_package(VersionedPackage::default()/* use setters */);
assert!(x.zypper_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn googet_package(&self) -> Option<&Box<VersionedPackage>>
pub fn googet_package(&self) -> Option<&Box<VersionedPackage>>
The value of details
if it holds a GoogetPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_googet_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
pub fn set_googet_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
Sets the value of details
to hold a GoogetPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_googet_package(VersionedPackage::default()/* use setters */);
assert!(x.googet_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn zypper_patch(&self) -> Option<&Box<ZypperPatch>>
pub fn zypper_patch(&self) -> Option<&Box<ZypperPatch>>
The value of details
if it holds a ZypperPatch, None if the field is not set or
holds a different branch.
Sourcepub fn set_zypper_patch<T: Into<Box<ZypperPatch>>>(self, v: T) -> Self
pub fn set_zypper_patch<T: Into<Box<ZypperPatch>>>(self, v: T) -> Self
Sets the value of details
to hold a ZypperPatch.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::ZypperPatch;
let x = SoftwarePackage::new().set_zypper_patch(ZypperPatch::default()/* use setters */);
assert!(x.zypper_patch().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn wua_package(&self) -> Option<&Box<WindowsUpdatePackage>>
pub fn wua_package(&self) -> Option<&Box<WindowsUpdatePackage>>
The value of details
if it holds a WuaPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_wua_package<T: Into<Box<WindowsUpdatePackage>>>(self, v: T) -> Self
pub fn set_wua_package<T: Into<Box<WindowsUpdatePackage>>>(self, v: T) -> Self
Sets the value of details
to hold a WuaPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::WindowsUpdatePackage;
let x = SoftwarePackage::new().set_wua_package(WindowsUpdatePackage::default()/* use setters */);
assert!(x.wua_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn qfe_package(&self) -> Option<&Box<WindowsQuickFixEngineeringPackage>>
pub fn qfe_package(&self) -> Option<&Box<WindowsQuickFixEngineeringPackage>>
The value of details
if it holds a QfePackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_qfe_package<T: Into<Box<WindowsQuickFixEngineeringPackage>>>(
self,
v: T,
) -> Self
pub fn set_qfe_package<T: Into<Box<WindowsQuickFixEngineeringPackage>>>( self, v: T, ) -> Self
Sets the value of details
to hold a QfePackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::WindowsQuickFixEngineeringPackage;
let x = SoftwarePackage::new().set_qfe_package(WindowsQuickFixEngineeringPackage::default()/* use setters */);
assert!(x.qfe_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.cos_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn cos_package(&self) -> Option<&Box<VersionedPackage>>
pub fn cos_package(&self) -> Option<&Box<VersionedPackage>>
The value of details
if it holds a CosPackage, None if the field is not set or
holds a different branch.
Sourcepub fn set_cos_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
pub fn set_cos_package<T: Into<Box<VersionedPackage>>>(self, v: T) -> Self
Sets the value of details
to hold a CosPackage.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::VersionedPackage;
let x = SoftwarePackage::new().set_cos_package(VersionedPackage::default()/* use setters */);
assert!(x.cos_package().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.windows_application().is_none());Sourcepub fn windows_application(&self) -> Option<&Box<WindowsApplication>>
pub fn windows_application(&self) -> Option<&Box<WindowsApplication>>
The value of details
if it holds a WindowsApplication, None if the field is not set or
holds a different branch.
Sourcepub fn set_windows_application<T: Into<Box<WindowsApplication>>>(
self,
v: T,
) -> Self
pub fn set_windows_application<T: Into<Box<WindowsApplication>>>( self, v: T, ) -> Self
Sets the value of details
to hold a WindowsApplication.
Note that all the setters affecting details are
mutually exclusive.
Example
use google_cloud_osconfig_v1::model::inventory::WindowsApplication;
let x = SoftwarePackage::new().set_windows_application(WindowsApplication::default()/* use setters */);
assert!(x.windows_application().is_some());
assert!(x.yum_package().is_none());
assert!(x.apt_package().is_none());
assert!(x.zypper_package().is_none());
assert!(x.googet_package().is_none());
assert!(x.zypper_patch().is_none());
assert!(x.wua_package().is_none());
assert!(x.qfe_package().is_none());
assert!(x.cos_package().is_none());Trait Implementations
Sourceimpl Clone for SoftwarePackage
impl Clone for SoftwarePackage
Sourcefn clone(&self) -> SoftwarePackage
fn clone(&self) -> SoftwarePackage
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SoftwarePackage
impl Debug for SoftwarePackage
Sourceimpl Default for SoftwarePackage
impl Default for SoftwarePackage
Sourcefn default() -> SoftwarePackage
fn default() -> SoftwarePackage
Sourceimpl Message for SoftwarePackage
impl Message for SoftwarePackage
Sourceimpl PartialEq for SoftwarePackage
impl PartialEq for SoftwarePackage
impl StructuralPartialEq for SoftwarePackage