#[non_exhaustive]pub struct OSPolicyAssignmentReport {
pub name: String,
pub instance: String,
pub os_policy_assignment: String,
pub os_policy_compliances: Vec<OSPolicyCompliance>,
pub update_time: Option<Timestamp>,
pub last_run_id: String,
/* private fields */
}Expand description
A report of the OS policy assignment status for a given instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe OSPolicyAssignmentReport API resource name.
Format:
projects/{project_number}/locations/{location}/instances/{instance_id}/osPolicyAssignments/{os_policy_assignment_id}/report
instance: StringThe Compute Engine VM instance name.
os_policy_assignment: StringReference to the OSPolicyAssignment API resource that the OSPolicy
belongs to.
Format:
projects/{project_number}/locations/{location}/osPolicyAssignments/{os_policy_assignment_id@revision_id}
os_policy_compliances: Vec<OSPolicyCompliance>Compliance data for each OSPolicy that is applied to the VM.
update_time: Option<Timestamp>Timestamp for when the report was last generated.
last_run_id: StringUnique identifier of the last attempted run to apply the OS policies associated with this assignment on the VM.
This ID is logged by the OS Config agent while applying the OS policies associated with this assignment on the VM. NOTE: If the service is unable to successfully connect to the agent for this run, then this id will not be available in the agent logs.
Implementations
Sourceimpl OSPolicyAssignmentReport
impl OSPolicyAssignmentReport
Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_os_policy_assignment<T: Into<String>>(self, v: T) -> Self
pub fn set_os_policy_assignment<T: Into<String>>(self, v: T) -> Self
Sets the value of os_policy_assignment.
Example
let x = OSPolicyAssignmentReport::new().set_os_policy_assignment(format!("projects/{project_id}/locations/{location_id}/osPolicyAssignments/{os_policy_assignment_id}"));Sourcepub fn set_os_policy_compliances<T, V>(self, v: T) -> Self
pub fn set_os_policy_compliances<T, V>(self, v: T) -> Self
Sets the value of os_policy_compliances.
Example
use google_cloud_osconfig_v1::model::os_policy_assignment_report::OSPolicyCompliance;
let x = OSPolicyAssignmentReport::new()
.set_os_policy_compliances([
OSPolicyCompliance::default()/* use setters */,
OSPolicyCompliance::default()/* use (different) setters */,
]);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = OSPolicyAssignmentReport::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = OSPolicyAssignmentReport::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = OSPolicyAssignmentReport::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_last_run_id<T: Into<String>>(self, v: T) -> Self
pub fn set_last_run_id<T: Into<String>>(self, v: T) -> Self
Sets the value of last_run_id.
Example
let x = OSPolicyAssignmentReport::new().set_last_run_id("example");Trait Implementations
Sourceimpl Clone for OSPolicyAssignmentReport
impl Clone for OSPolicyAssignmentReport
Sourcefn clone(&self) -> OSPolicyAssignmentReport
fn clone(&self) -> OSPolicyAssignmentReport
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OSPolicyAssignmentReport
impl Debug for OSPolicyAssignmentReport
Sourceimpl Default for OSPolicyAssignmentReport
impl Default for OSPolicyAssignmentReport
Sourcefn default() -> OSPolicyAssignmentReport
fn default() -> OSPolicyAssignmentReport
Sourceimpl Message for OSPolicyAssignmentReport
impl Message for OSPolicyAssignmentReport
Sourceimpl PartialEq for OSPolicyAssignmentReport
impl PartialEq for OSPolicyAssignmentReport
impl StructuralPartialEq for OSPolicyAssignmentReport