#[non_exhaustive]pub struct PatchJob {Show 15 fields
pub name: String,
pub display_name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub state: State,
pub instance_filter: Option<PatchInstanceFilter>,
pub patch_config: Option<PatchConfig>,
pub duration: Option<Duration>,
pub instance_details_summary: Option<InstanceDetailsSummary>,
pub dry_run: bool,
pub error_message: String,
pub percent_complete: f64,
pub patch_deployment: String,
pub rollout: Option<PatchRollout>,
/* private fields */
}Expand description
A high level representation of a patch job that is either in progress or has completed.
Instance details are not included in the job. To paginate through instance details, use ListPatchJobInstanceDetails.
For more information about patch jobs, see Creating patch jobs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringUnique identifier for this patch job in the form
projects/*/patchJobs/*
display_name: StringDisplay name for this patch job. This is not a unique identifier.
description: StringDescription of the patch job. Length of the description is limited to 1024 characters.
create_time: Option<Timestamp>Time this patch job was created.
update_time: Option<Timestamp>Last time this patch job was updated.
state: StateThe current state of the PatchJob.
instance_filter: Option<PatchInstanceFilter>Instances to patch.
patch_config: Option<PatchConfig>Patch configuration being applied.
duration: Option<Duration>Duration of the patch job. After the duration ends, the patch job times out.
instance_details_summary: Option<InstanceDetailsSummary>Summary of instance details.
dry_run: boolIf this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance.
error_message: StringIf this patch job failed, this message provides information about the failure.
percent_complete: f64Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete.
patch_deployment: StringOutput only. Name of the patch deployment that created this patch job.
rollout: Option<PatchRollout>Rollout strategy being applied.
Implementations
Sourceimpl PatchJob
impl PatchJob
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = PatchJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = PatchJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PatchJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PatchJob::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PatchJob::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PatchJob::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_instance_filter<T>(self, v: T) -> Selfwhere
T: Into<PatchInstanceFilter>,
pub fn set_instance_filter<T>(self, v: T) -> Selfwhere
T: Into<PatchInstanceFilter>,
Sets the value of instance_filter.
Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = PatchJob::new().set_instance_filter(PatchInstanceFilter::default()/* use setters */);Sourcepub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchInstanceFilter>,
pub fn set_or_clear_instance_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchInstanceFilter>,
Sets or clears the value of instance_filter.
Example
use google_cloud_osconfig_v1::model::PatchInstanceFilter;
let x = PatchJob::new().set_or_clear_instance_filter(Some(PatchInstanceFilter::default()/* use setters */));
let x = PatchJob::new().set_or_clear_instance_filter(None::<PatchInstanceFilter>);Sourcepub fn set_patch_config<T>(self, v: T) -> Selfwhere
T: Into<PatchConfig>,
pub fn set_patch_config<T>(self, v: T) -> Selfwhere
T: Into<PatchConfig>,
Sets the value of patch_config.
Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = PatchJob::new().set_patch_config(PatchConfig::default()/* use setters */);Sourcepub fn set_or_clear_patch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchConfig>,
pub fn set_or_clear_patch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchConfig>,
Sets or clears the value of patch_config.
Example
use google_cloud_osconfig_v1::model::PatchConfig;
let x = PatchJob::new().set_or_clear_patch_config(Some(PatchConfig::default()/* use setters */));
let x = PatchJob::new().set_or_clear_patch_config(None::<PatchConfig>);Sourcepub fn set_duration<T>(self, v: T) -> Self
pub fn set_duration<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
Sourcepub fn set_instance_details_summary<T>(self, v: T) -> Selfwhere
T: Into<InstanceDetailsSummary>,
pub fn set_instance_details_summary<T>(self, v: T) -> Selfwhere
T: Into<InstanceDetailsSummary>,
Sets the value of instance_details_summary.
Example
use google_cloud_osconfig_v1::model::patch_job::InstanceDetailsSummary;
let x = PatchJob::new().set_instance_details_summary(InstanceDetailsSummary::default()/* use setters */);Sourcepub fn set_or_clear_instance_details_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstanceDetailsSummary>,
pub fn set_or_clear_instance_details_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstanceDetailsSummary>,
Sets or clears the value of instance_details_summary.
Example
use google_cloud_osconfig_v1::model::patch_job::InstanceDetailsSummary;
let x = PatchJob::new().set_or_clear_instance_details_summary(Some(InstanceDetailsSummary::default()/* use setters */));
let x = PatchJob::new().set_or_clear_instance_details_summary(None::<InstanceDetailsSummary>);Sourcepub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
pub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_error_message<T: Into<String>>(self, v: T) -> Self
pub fn set_error_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_percent_complete<T: Into<f64>>(self, v: T) -> Self
pub fn set_percent_complete<T: Into<f64>>(self, v: T) -> Self
Sourcepub fn set_patch_deployment<T: Into<String>>(self, v: T) -> Self
pub fn set_patch_deployment<T: Into<String>>(self, v: T) -> Self
Sets the value of patch_deployment.
Example
let x = PatchJob::new().set_patch_deployment(format!("projects/{project_id}/patchDeployments/{patch_deployment_id}"));Sourcepub fn set_rollout<T>(self, v: T) -> Selfwhere
T: Into<PatchRollout>,
pub fn set_rollout<T>(self, v: T) -> Selfwhere
T: Into<PatchRollout>,
Sourcepub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchRollout>,
pub fn set_or_clear_rollout<T>(self, v: Option<T>) -> Selfwhere
T: Into<PatchRollout>,